@@ -525,15 +525,15 @@ void segatex::segatex_show_interface()
 					const char* den = "denied";
 					const char* log_time = "audit\\([0-9]{10}";
 					const char* scontext = "scontext([^[:blank:]]*)([:blank:])?";
-					const char* scontext_rev = "t_[a-z0-9_]([^:]*)?";
+					const char* scontext_rev = "t_[a-zA-Z0-9_]([^:]*)?";
 					const char* tcontext = "tcontext([^[:blank:]]*)([:blank:])?";
-					const char* tcontext_rev = "t_[a-z0-9_]([^:]*)?";
+					const char* tcontext_rev = "t_[a-zA-Z0-9_]([^:]*)?";
 					//changed in segatex2.11
 					//const char* tclass = "tclass(.*)";
-					const char* tclass = "tclass=[a-z0-9_]*";
-					const char* tclass_2 = "[a-z0-9_]([^=]*)?";
+					const char* tclass = "tclass=[a-zA-Z0-9_]*";
+					const char* tclass_2 = "[a-zA-Z0-9_]([^=]*)?";
 					const char* acc = "\\{(.*)\\}";
-					const char* role = ":[a-z0-9_]*_r";
+					const char* role = ":[a-zA-Z0-9_]*_r";
 
 					regex denied_exp(den);
 					regex log_time_exp(log_time);
@@ -635,7 +635,7 @@ void segatex::segatex_show_interface()
 						if(regex_search(source,what,denied_exp)){
 							if(regex_search(source,what,domain_exp)){
 								domain = what[0];
-								//os_policy << domain << endl;
+								//os_policy << "domain:" << domain << endl;
 								const char* domain_char = domain.c_str();
 								if(regex_search(domain_char,what,role_exp)){
 									role_str = what[0];
@@ -727,6 +727,7 @@ void segatex::segatex_show_interface()
 								log_time_int = atoi(log_time_string.c_str());
 							}
 							if(log_from_time_int <= log_time_int){
+								//os_policy << policy_selinux << endl;
 								v2.push_back(policy_selinux.c_str());
 							}
 						  }
@@ -738,9 +739,9 @@ void segatex::segatex_show_interface()
 					const char* m_domain_pre = "[A-Za-z0-9_]*_t";
 					const char* m_tclass_pre = "[A-Za-z0-9_]*_t:";
 					//changed here at segatex2.11
-					const char* m_objclass_pre = ":[a-z0-9_]*([^[:space:]]*)([:space:])?";
+					const char* m_objclass_pre = ":[a-zA-Z0-9_]*([^[:space:]]*)([:space:])?";
 					const char* m_acc = "\\{(.*)\\}";
-					const char* m_blank = "[a-z0-9_](.*)[a-z0-9_]";
+					const char* m_blank = "[a-zA-Z0-9_](.*)[a-zA-Z0-9_]";
 					regex m_pre_exp(m_pre);
 					regex m_interface_pre_exp(m_interface_pre);
 					regex m_domain_pre_exp(m_domain_pre);
@@ -838,7 +839,7 @@ void segatex::segatex_show_interface()
 						//os_policy << "source_interface_pre:" << source_interface_pre << endl;
 						//const char* m_interface_accv = ":(.*)\\{(.*)\\}";
 						const char* m_interface_accv_pre = ":(.*)\\}";
-						const char* m_interface_accv = "(:[a-z0-9_]*)[[:space:]]";
+						const char* m_interface_accv = "(:[a-zA-Z0-9_]*)[[:space:]]";
 						//segatex2.12ɮ
 						const char* m_auth_domtrans = "auth_domtrans";
 						const char* m_bin_domtrans = "bin_domtrans";
@@ -853,6 +854,7 @@ void segatex::segatex_show_interface()
 						const char* m_kernel_modules_filetrans = "kernel_modules_filetrans";
 						const char* m_lock_filetrans = "lock_filetrans";
 						const char* m_pid_filetrans = "pid_filetrans";
+						const char* m_usr_filetrans = "usr_filetrans";
 						const char* m_tmp_filetrans = "tmp_filetrans";
 						const char* m_var_filetrans = "var_filetrans";
 						const char* m_var_lib_filetrans = "var_lib_filetrans";
@@ -863,6 +865,7 @@ void segatex::segatex_show_interface()
 						const char* m_sysadm_home_dir_filetrans = "userdom_sysadm_home_dir_filetrans";
 						const char* m_create_pty = "create_pty";
 						const char* m_cron_system_entry = "cron_system_entry";
+						const char* m_kernel_sendrecv_unlabeled_association = "kernel_sendrecv_unlabeled_association";
 						regex m_interface_accv_exp(m_interface_accv);
 						regex m_interface_accv_pre_exp(m_interface_accv_pre);
 						regex m_auth_domtrans_exp(m_auth_domtrans);
@@ -879,6 +882,7 @@ void segatex::segatex_show_interface()
 						regex m_lock_filetrans_exp(m_lock_filetrans);
 						regex m_pid_filetrans_exp(m_pid_filetrans);
 						regex m_tmp_filetrans_exp(m_tmp_filetrans);
+						regex m_usr_filetrans_exp(m_usr_filetrans);
 						regex m_var_filetrans_exp(m_var_filetrans);
 						regex m_var_lib_filetrans_exp(m_var_lib_filetrans);
 						regex m_tmpfs_filetrans_exp(m_tmpfs_filetrans);
@@ -888,12 +892,53 @@ void segatex::segatex_show_interface()
 						regex m_sysadm_home_dir_filetrans_exp(m_sysadm_home_dir_filetrans);
 						regex m_create_pty_exp(m_create_pty);
 						regex m_cron_system_entry_exp(m_cron_system_entry);
+						regex m_kernel_sendrecv_unlabeled_association_exp(m_kernel_sendrecv_unlabeled_association);
 						string source_interface_accv_pre;
 						string source_interface_accv;
+						string packet_str="packet";
+						string send_str="send";
+						string recv_str="recv";
+															string pair_process="process";
+															string paired_transition="transition";
+															string paired_siginh="siginh";
+															string paired_rlimitinh="rlimitinh";
+															string paired_noatsecure="noatsecure";
+
+															string pair_association="association";
+															string paired_sendto="sendto";
+															string paired_recvfrom="recvfrom";
+
+															string pair_packet="packet";
+															string paired_send="send";
+															string paired_recv="recv";
+
+															string pair_netif="netif";
+															string paired_tcp_send="tcp_send";
+															string paired_tcp_recv="tcp_recv";
+															string paired_udp_send="udp_send";
+															string paired_udp_recv="udp_recv";
+
+															string pair_node="node";
+
+															string pair_tcp_socket="tcp_socket";
+															string paired_send_msg="send_msg";
+															string paired_recv_msg="recv_msg";
+															string paired_node_bind="node_bind";
+															string paired_name_bind="name_bind";
+															string paired_name_connect="name_connect";
+
+															string pair_udp_socket="udp_socket";
+
+															string pair_capability="capability";
+															string paired_net_bind_service="net_bind_service";
+
+															string pair_security="security";
+															string paired_setbool="setbool";
+															string paired_setenforce="setenforce";
 
 						cmatch what;
 						string blank_str = " ";
-						regex re("[a-z0-9_]*,");
+						regex re("[a-zA-Z0-9_]*,");
 						string plus_source_interface_pre = blank_str + source_interface_pre;
 						//os_policy << "plus_source_interface_pre:" << plus_source_interface_pre << endl;
 						const char* m_engine = plus_source_interface_pre.c_str();
@@ -933,7 +978,7 @@ void segatex::segatex_show_interface()
 									int bracket_first_position=source_interface_accv_pre.find_first_of(bracket_first_str);
 									source_interface_accv_pre=source_interface_accv_pre.replace(0,bracket_first_position + 1,blank_str);
 									//os_policy << source_interface_accv_pre << endl;
-									regex tmp_re("[[:space:]]([^[:space:]]*)[a-z0-9_]*");
+									regex tmp_re("[[:space:]]([^[:space:]]*)[a-zA-Z0-9_]*");
 									string::const_iterator it=source_interface_accv_pre.begin(), end=source_interface_accv_pre.end();
 									while(it != end){
 										smatch result;
@@ -1007,43 +1052,6 @@ void segatex::segatex_show_interface()
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															//¤ʤʤΤƤΤǡŪѤǤ
-string pair_process="process";
-string paired_transition="transition";
-string paired_siginh="siginh";
-string paired_rlimitinh="rlimitinh";
-string paired_noatsecure="noatsecure";
-
-string pair_association="association";
-string paired_sendto="sendto";
-string paired_recvfrom="recvfrom";
-
-string pair_packet="packet";
-string paired_send="send";
-string paired_recv="recv";
-
-string pair_netif="netif";
-string paired_tcp_send="tcp_send";
-string paired_tcp_recv="tcp_recv";
-string paired_udp_send="udp_send";
-string paired_udp_recv="udp_recv";
-
-string pair_node="node";
-
-string pair_tcp_socket="tcp_socket";
-string paired_send_msg="send_msg";
-string paired_recv_msg="recv_msg";
-string paired_node_bind="node_bind";
-string paired_name_bind="name_bind";
-string paired_name_connect="name_connect";
-
-string pair_udp_socket="udp_socket";
-
-string pair_capability="capability";
-string paired_net_bind_service="net_bind_service";
-
-string pair_security="security";
-string paired_setbool="setbool";
-string paired_setenforce="setenforce";
 															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_transition));
 															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_siginh));
 															pattern_not_matched_access_vector.insert(pair<string, string>(pair_process,paired_rlimitinh));
@@ -1091,77 +1099,83 @@ string paired_setenforce="setenforce";
 														//boot_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_boot_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="boot_runtime_t";
+															domain_dollar_2="boot_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//etc_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_etc_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="etc_runtime_t";
+															domain_dollar_2="etc_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//home_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_home_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="home_runtime_t";
+															domain_dollar_2="home_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//kernel_modules_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_kernel_modules_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="kernel_modules_runtime_t";
+															domain_dollar_2="kernel_modules_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//lock_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_lock_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="lock_runtime_t";
+															domain_dollar_2="lock_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//pid_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_pid_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="pid_runtime_t";
+															domain_dollar_2="pid_tmp_t";
+															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
+															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
+														//usr_filetransξ
+														}else if(regex_search(result_str.c_str(),what,m_usr_filetrans_exp)){
+															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
+															domain_dollar_2="usr_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//tmp_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_tmp_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															string tmp_filetrans_echo="tmp_runtime_t";
+															string tmp_filetrans_echo="tmp_t";
 															domain_dollar_2=p_pattern_not_matched_domain->second;
 															int length=strlen(domain_dollar_2.c_str());
-															domain_dollar_2=domain_dollar_2.replace(length -2,2,blank_str);
+															domain_dollar_2=domain_dollar_2.replace(length -1,2,blank_str);
 															domain_dollar_2= domain_dollar_2 + tmp_filetrans_echo;
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//var_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_var_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="var_runtime_t";
+															domain_dollar_2="var_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//var_lib_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_var_lib_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="var_lib_runtime_t";
+															domain_dollar_2="var_lib_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//tmpfs_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_tmpfs_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="tmpfs_runtime_t";
+															domain_dollar_2="tmpfs_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//log_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_log_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="log_runtime_t";
+															domain_dollar_2="log_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//spool_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_spool_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="spool_runtime_t";
+															domain_dollar_2="spool_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//home_dir_filetransξ
@@ -1170,7 +1184,7 @@ string paired_setenforce="setenforce";
 														//sysadm_home_dir_filetransξ
 														}else if(regex_search(result_str.c_str(),what,m_sysadm_home_dir_filetrans_exp)){
 															//ܺѤߥɥᥤѤǤǥå󥳤type ... ;ȤƽФ򤹤
-															domain_dollar_2="sysadm_home_dir_runtime_t";
+															domain_dollar_2="sysadm_home_dir_tmp_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + comma_str + private_type + bracket_last_str;  
 														//create_ptyξ
@@ -1189,6 +1203,17 @@ string paired_setenforce="setenforce";
 															domain_dollar_2="anacron_exec_t";
 															v_dollar_2_domain.push_back(domain_dollar_2.c_str());
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + comma_str + domain_dollar_2 + bracket_last_str;  
+														//kernel_sendrecv_unlabeled_association
+														}else if(regex_search(result_str.c_str(),what,m_kernel_sendrecv_unlabeled_association_exp)){
+														//os_policy << "oohps !" << endl;
+														//multimapȥ٥ξѤǤɬפ
+														pattern_not_matched_access_vector.insert(pair<string, string>(packet_str,send_str));
+														pattern_not_matched_access_vector.insert(pair<string, string>(packet_str,recv_str));
+														v_matched_tmp_objclass.push_back(packet_str.c_str());
+														pattern_not_matched_access_vector.insert(pair<string, string>(pair_tcp_socket,paired_node_bind));
+														v_matched_tmp_objclass.push_back(pair_tcp_socket.c_str());
+														pattern_not_matched_access_vector.insert(pair<string, string>(pair_udp_socket,paired_node_bind));
+														v_matched_tmp_objclass.push_back(pair_udp_socket.c_str());
 														}else{
 															domain_interface_echo = result_str + bracket_first_str + domain_dollar_1 + bracket_last_str;  
 														}
@@ -1247,7 +1272,7 @@ string paired_setenforce="setenforce";
 						if(p_pattern_not_matched_objclass != pattern_not_matched_objclass.end()){
 							do{
 								//os_policy << "matcheʤäobjclass:" << p_pattern_not_matched_objclass->second << ";" << endl;
-								// 2ܤϡ826
+								// 2ܤϡ826(old description)
 								v_tmp_objclass.push_back(p_pattern_not_matched_objclass->second.c_str());
 								p_pattern_not_matched_objclass++;
 							}while(p_pattern_not_matched_objclass != pattern_not_matched_objclass.upper_bound(source_interface_pre));
@@ -1301,17 +1326,17 @@ string paired_setenforce="setenforce";
 
 
 
-					const char* m_domain_interface_h = "[a-z][a-z0-9_]*_t:";
+					const char* m_domain_interface_h = "[a-zA-Z][a-zA-Z0-9_]*_t:";
 					const char* m_domain_interface_h_204 = "allow(.*)_t";
-					const char* m_domain_interface_h_204_2 = "[[:space:]][a-z][a-z0-9_]*_t";
+					const char* m_domain_interface_h_204_2 = "[[:space:]][a-zA-Z][a-zA-Z0-9_]*_t";
 					const char* m_objclass_interface_h = ":.*?\\{";
-					const char* m_objclass_interface_h_dash = ":[a-z0-9_]*";
+					const char* m_objclass_interface_h_dash = ":[a-zA-Z0-9_]*";
 					const char* m_objclass_interface_h2 = ":(.*)([^[:space:]*])[[:space:]]";
 					//ǡ{{}}ȤΤȤʤ褦ˤʤ̵äݤΤǡǤ뤫
 					//segatex2.05ɮʾ嵭ؤˤʤäƤ
 					const char* m_accv_interface_h = "\\{(.*)\\}";
 					const char* m_accv_interface_h_special = "\\{(.*)\\}:";
-					const char* m_accv_interface_h2 = "[[:space:]][a-z0-9_]*;,";
+					const char* m_accv_interface_h2 = "[[:space:]][a-zA-Z0-9_]*;,";
 					string blank_str="";
 					string space_str=" ";
 					string tiruda_str="~";
@@ -1428,8 +1453,8 @@ string paired_setenforce="setenforce";
 								//os_policy << accv_interface_h << endl;	
 
 								//segatex2.05ɮʤ󡢤ޤʡ
-								regex tmp_re("[[:space:]]([^[:space:]]*)[a-z0-9_]*");
-								regex tmp_re2("[[:space:]][a-z0-9_]*_t");
+								regex tmp_re("[[:space:]]([^[:space:]]*)[a-zA-Z0-9_]*");
+								regex tmp_re2("[[:space:]][a-zA-Z0-9_]*_t");
 								string::const_iterator it=accv_interface_h.begin(), end=accv_interface_h.end();
 								while(it != end-1){
 									smatch result;
@@ -1509,7 +1534,7 @@ string paired_setenforce="setenforce";
 					p_tmp_objclass_end=unique(v_tmp_objclass.begin(),v_tmp_objclass.end());
 
 					os_policy << "####################################################" << endl;
-					os_policy << "##### This file was generated by segatex2.12" << endl;
+					os_policy << "##### This file was generated by segatex2.13" << endl;
 					os_policy << "####################################################" << endl;
 					os_policy << "module my_policy_by_segatex 1.0.0;" << endl << endl;
 					os_policy << "require {" << endl;
